@@ -6,7 +6,7 @@ package Excel::Writer::XLSX::Drawing;
 #
 # Used in conjunction with Excel::Writer::XLSX
 #
-# Copyright 2000-2021, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2023, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -21,7 +21,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Worksheet;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '1.09';
+our $VERSION = '1.11';
 
 
 ###############################################################################
@@ -182,12 +182,13 @@ sub _write_two_cell_anchor {
     my $row_absolute    = $dimensions->[9];
     my $width           = $drawing_object->{_width};
     my $height          = $drawing_object->{_height};
-    my $description     = $drawing_object->{_description};
     my $shape           = $drawing_object->{_shape};
     my $anchor          = $drawing_object->{_anchor};
     my $rel_index       = $drawing_object->{_rel_index};
     my $url_rel_index   = $drawing_object->{_url_rel_index};
     my $tip             = $drawing_object->{_tip};
+    my $name            = $drawing_object->{_name};
+    my $description     = $drawing_object->{_description};
     my $decorative      = $drawing_object->{_decorative};
 
     my @attributes = ();
@@ -228,7 +229,8 @@ sub _write_two_cell_anchor {
         # Graphic frame.
 
         # Write the xdr:graphicFrame element for charts.
-        $self->_write_graphic_frame( $index, $rel_index, $description );
+        $self->_write_graphic_frame( $index, $rel_index, $name, $description,
+            $decorative );
     }
     elsif ( $type == 2 ) {
 
@@ -471,18 +473,20 @@ sub _write_xdr_ext {
 #
 sub _write_graphic_frame {
 
-    my $self      = shift;
-    my $index     = shift;
-    my $rel_index = shift;
-    my $name      = shift;
-    my $macro     = '';
+    my $self        = shift;
+    my $index       = shift;
+    my $rel_index   = shift;
+    my $name        = shift;
+    my $description = shift;
+    my $decorative  = shift;
+    my $macro       = '';
 
     my @attributes = ( 'macro' => $macro );
 
     $self->xml_start_tag( 'xdr:graphicFrame', @attributes );
 
     # Write the xdr:nvGraphicFramePr element.
-    $self->_write_nv_graphic_frame_pr( $index, $name );
+    $self->_write_nv_graphic_frame_pr( $index, $name, $description, $decorative );
 
     # Write the xdr:xfrm element.
     $self->_write_xfrm();
@@ -502,9 +506,11 @@ sub _write_graphic_frame {
 #
 sub _write_nv_graphic_frame_pr {
 
-    my $self  = shift;
-    my $index = shift;
-    my $name  = shift;
+    my $self        = shift;
+    my $index       = shift;
+    my $name        = shift;
+    my $description = shift;
+    my $decorative  = shift;
 
     if ( !$name ) {
         $name = 'Chart ' . $index;
@@ -513,7 +519,8 @@ sub _write_nv_graphic_frame_pr {
     $self->xml_start_tag( 'xdr:nvGraphicFramePr' );
 
     # Write the xdr:cNvPr element.
-    $self->_write_c_nv_pr( $index + 1, $name );
+    $self->_write_c_nv_pr( $index + 1, $name, $description,
+                           undef, undef, $decorative );
 
     # Write the xdr:cNvGraphicFramePr element.
     $self->_write_c_nv_graphic_frame_pr();
@@ -1580,7 +1587,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-(c) MM-MMXXI, John McNamara.
+(c) MM-MMXXIII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
